@@ -310,7 +310,7 @@ class NavSoapClient():
         serialized_response = serialize_object(soap_response)
         return serialized_response
 
-    def retrieve_unit(self, cust_no, site_code, rental_order, unit_id, retrieval_date, billing_end, engine_hours):
+    def retrieve_unit(self, cust_no, site_code, return_location, rental_order, unit_id, retrieval_date, billing_end, engine_hours):
         """
         Use this when a unit is retrieved from a site, to remove the unit from the rental order.
         rental_order, unit_id, retrieval_date, and billing_end require values, all else should be empty strings.
@@ -326,6 +326,7 @@ class NavSoapClient():
         soap_response = client.service.ReturnEquip(
             custNo = cust_no,
             siteCode = site_code,
+            returnLocation = return_location,
             rentalOrderNo = rental_order,
             equipNo = unit_id,
             returnDate = retrieval_date,
